import { Create, useForm } from "@refinedev/antd";
import { Form, Input, Select, Tabs } from "antd";
import { useState } from "react";
import { AppFormData, AppType } from "../../types/app";

const { TabPane } = Tabs;

export const AppCreate = () => {
  const { formProps, saveButtonProps } = useForm<AppFormData>({});
  const [appType, setAppType] = useState<AppType>("frontend");

  const handleTypeChange = (value: AppType) => {
    setAppType(value);
  };

  return (
    <Create saveButtonProps={saveButtonProps}>
      <Form {...formProps} layout="vertical">
        <Form.Item
          label={"App Name"}
          name="name"
          rules={[{ required: true }]}
        >
          <Input />
        </Form.Item>

        <Form.Item
          label={"Description"}
          name="description"
          rules={[{ required: true }]}
        >
          <Input.TextArea rows={3} />
        </Form.Item>

        <Form.Item
          label={"App Type"}
          name="type"
          initialValue="frontend"
          rules={[{ required: true }]}
        >
          <Select
            options={[
              { value: "frontend", label: "Frontend Application" },
              { value: "backend", label: "Backend Service" },
              { value: "api", label: "API Service" },
              { value: "database", label: "Database" },
              { value: "microservice", label: "Microservice" },
            ]}
            onChange={handleTypeChange}
          />
        </Form.Item>

        <Form.Item
          label={"Language/Framework"}
          name="language"
          rules={[{ required: true }]}
        >
          <Select
            options={
              appType === "frontend" 
                ? [
                  { value: "reactjs", label: "React JS" },
                  { value: "vuejs", label: "Vue JS" },
                  { value: "angular", label: "Angular" },
                  { value: "nextjs", label: "Next.js" },
                ] 
                : appType === "database"
                ? [
                  { value: "postgresql", label: "PostgreSQL" },
                  { value: "mysql", label: "MySQL" },
                  { value: "mongodb", label: "MongoDB" },
                  { value: "redis", label: "Redis" },
                ]
                : [
                  { value: "nodejs", label: "Node.js" },
                  { value: "python", label: "Python" },
                  { value: "java", label: "Java" },
                  { value: "golang", label: "Go" },
                  { value: "dotnet", label: ".NET Core" },
                ]
            }
          />
        </Form.Item>

        <Form.Item
          label={"Version"}
          name="version"
          initialValue={"1.0.0"}
          rules={[{ required: true }]}
        >
          <Input />
        </Form.Item>

        <Tabs defaultActiveKey="configuration">
          <TabPane tab="Configuration" key="configuration">
            <Form.Item
              label={"Configuration File"}
              name="configFile"
              rules={[{ required: true }]}
            >
              <Input.TextArea rows={10} placeholder={
                appType === "frontend" 
                  ? `{\n  "name": "frontend-app",\n  "port": 3000,\n  "environment": "production",\n  "resources": {\n    "cpu": "0.5",\n    "memory": "512Mi"\n  }\n}`
                  : appType === "backend" || appType === "api"
                  ? `{\n  "name": "api-service",\n  "port": 8080,\n  "environment": "production",\n  "resources": {\n    "cpu": "1",\n    "memory": "1Gi"\n  },\n  "scaling": {\n    "min": 2,\n    "max": 5\n  }\n}`
                  : `{\n  "name": "database",\n  "type": "postgres",\n  "version": "13",\n  "storage": "10Gi",\n  "backups": true\n}`
              } />
            </Form.Item>
          </TabPane>

          <TabPane tab="Environment Variables" key="env-vars">
            <Form.Item
              label={"Environment Variables"}
              name="envVariables"
            >
              <Input.TextArea rows={5} placeholder={`PORT=8080\nNODE_ENV=production\nDATABASE_URL=postgresql://user:password@localhost:5432/db\nAPI_KEY=your-api-key`} />
            </Form.Item>
          </TabPane>

          <TabPane tab="Source Code" key="source-code">
            <Form.Item
              label={"Source Code Repository"}
              name="repository"
            >
              <Input placeholder="https://github.com/username/repo" />
            </Form.Item>
            
            <Form.Item
              label={"Branch"}
              name="branch"
              initialValue={"main"}
            >
              <Input />
            </Form.Item>

            <Form.Item
              label={"Build Command"}
              name="buildCommand"
            >
              <Input placeholder="npm install && npm run build" />
            </Form.Item>
          </TabPane>

          <TabPane tab="Advanced Settings" key="advanced">
            <Form.Item
              label={"Resource Requirements"}
              name="resources"
            >
              <Input.TextArea rows={4} placeholder={`CPU: 0.5\nMemory: 512Mi\nStorage: 1Gi`} />
            </Form.Item>
            
            <Form.Item
              label={"Scale Settings"}
              name="scaleSettings"
            >
              <Input.TextArea rows={3} placeholder={`Min Instances: 2\nMax Instances: 5\nCPU Threshold: 75%`} />
            </Form.Item>
          </TabPane>
        </Tabs>
      </Form>
    </Create>
  );
}
