import { Show, TextField, TagField } from "@refinedev/antd";
import { useShow } from "@refinedev/core";
import { Typography, Card, Descriptions, Tabs, Badge, Divider, Button, Row, Col, Tag, Alert } from "antd";
import { CodeOutlined, BranchesOutlined, ApiOutlined, DatabaseOutlined } from '@ant-design/icons';

const { Title, Text } = Typography;
const { TabPane } = Tabs;

export const AppShow = () => {
  const { queryResult } = useShow({});
  const { data, isLoading } = queryResult;
  const record = data?.data;

  // Function to get an icon based on app type
  const getAppTypeIcon = (type: string) => {
    switch (type) {
      case 'frontend':
        return <span role="img" aria-label="frontend">🖥️</span>;
      case 'backend':
        return <span role="img" aria-label="backend">⚙️</span>;
      case 'api':
        return <ApiOutlined />;
      case 'database':
        return <DatabaseOutlined />;
      case 'microservice':
        return <CodeOutlined />;
      default:
        return <CodeOutlined />;
    }
  };

  // Function to display color tag based on app type
  const getAppTypeTag = (type: string) => {
    const colorMap: Record<string, string> = {
      frontend: 'blue',
      backend: 'green',
      api: 'purple',
      database: 'orange',
      microservice: 'cyan',
    };
    
    return (
      <Tag color={colorMap[type] || 'default'}>
        {type?.toUpperCase()}
      </Tag>
    );
  };
  
  return (
    <Show isLoading={isLoading} 
      headerButtons={
        <>
          <Button type="primary">Deploy App</Button>
          <Button>Edit App</Button>
        </>
      }
    >
      <Title level={5}>App Information</Title>
      
      <Card>
        <Descriptions bordered column={2}>
          <Descriptions.Item label="App Name">{record?.name}</Descriptions.Item>
          <Descriptions.Item label="Type">
            {record?.type && (
              <div>
                {getAppTypeIcon(record.type)}{' '}
                {getAppTypeTag(record.type)}
              </div>
            )}
          </Descriptions.Item>
          <Descriptions.Item label="Language/Framework">
            <TagField value={record?.language} />
          </Descriptions.Item>
          <Descriptions.Item label="Version">{record?.version}</Descriptions.Item>
          <Descriptions.Item label="Description" span={2}>
            {record?.description}
          </Descriptions.Item>
        </Descriptions>
      </Card>

      <Divider />
      
      <Tabs defaultActiveKey="config">
        <TabPane 
          tab={<span><CodeOutlined /> Configuration</span>} 
          key="config"
        >
          <Card title="App Configuration">
            <pre style={{ backgroundColor: '#f5f5f5', padding: 16, borderRadius: 4 }}>
              {record?.configFile || '{\n  // No configuration available\n}'}
            </pre>
          </Card>
        </TabPane>
        
        <TabPane 
          tab={<span><BranchesOutlined /> Environment</span>} 
          key="env"
        >
          <Card title="Environment Variables">
            {record?.envVariables ? (
              <pre style={{ backgroundColor: '#f5f5f5', padding: 16, borderRadius: 4 }}>
                {record.envVariables}
              </pre>
            ) : (
              <Alert message="No environment variables have been defined" type="info" />
            )}
          </Card>
        </TabPane>
        
        <TabPane 
          tab={<span><CodeOutlined /> Source Code</span>} 
          key="source"
        >
          <Card>
            <Row gutter={16}>
              <Col span={12}>
                <Descriptions title="Repository Information" bordered column={1}>
                  <Descriptions.Item label="Repository URL">
                    {record?.repository || 'Not specified'}
                  </Descriptions.Item>
                  <Descriptions.Item label="Branch">
                    {record?.branch || 'main'}
                  </Descriptions.Item>
                  <Descriptions.Item label="Build Command">
                    {record?.buildCommand || 'Not specified'}
                  </Descriptions.Item>
                </Descriptions>
              </Col>
              <Col span={12}>
                <Card title="Last Commit" bordered={false}>
                  <Alert 
                    message="Source code tracking not enabled" 
                    description="Connect your repository to track commits and build status"
                    type="info"
                  />
                </Card>
              </Col>
            </Row>
          </Card>
        </TabPane>
        
        <TabPane 
          tab={<span>⚙️ Resources</span>} 
          key="resources"
        >
          <Card title="Resource Allocation">
            {record?.resources ? (
              <pre style={{ backgroundColor: '#f5f5f5', padding: 16, borderRadius: 4 }}>
                {record.resources}
              </pre>
            ) : (
              <Alert message="No resource requirements specified" type="info" />
            )}
          </Card>
          
          {record?.type !== 'database' && (
            <Card title="Scaling Configuration" style={{ marginTop: 16 }}>
              {record?.scaleSettings ? (
                <pre style={{ backgroundColor: '#f5f5f5', padding: 16, borderRadius: 4 }}>
                  {record.scaleSettings}
                </pre>
              ) : (
                <Alert message="No scaling settings defined" type="info" />
              )}
            </Card>
          )}
        </TabPane>
      </Tabs>
    </Show>
  );
};